<?php

// $Id: twinfield_usersync.admin.inc,v 1.1 2010/04/28 15:07:44 peterbex Exp $

/**
 * Menu callback for the twinfield-usersync settings form.
 */
function twinfield_usersync_admin_settings() {
  $credentials = variable_get(
    'twinfield_usersync_credentials',
    array('user' => '', 'password' => '', 'organisation' => '')
  );
  $old_selection = variable_get('twinfield_usersync_field_selection', array());
  
  $form = array('#tree' => true);

  $form['credentials']['user'] = array(
      '#type' => 'textfield',
      '#title' => t('Username'),
      '#default_value' => $credentials['user']
  );
  $form['credentials']['password'] = array(
      '#type' => 'password_confirm',
  );
  $form['credentials']['organisation'] = array(
      '#type' => 'textfield',
      '#title' => t('Organisation'),
      '#default_value' => $credentials['organisation']
  );
  
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Submit'),
    '#weight' => 10
  );

  $form['#submit'] = array('twinfield_usersync_admin_settings_submit');
  return $form;
}

function twinfield_usersync_admin_settings_submit($form, &$form_state) {
  $old_cred = variable_get('twinfield_usersync_credentials', array('password' => ''));
  if (empty($form_state['values']['credentials']['password'])) {
    $form_state['values']['credentials']['password'] = $old_cred['password'];
  }
  variable_set('twinfield_usersync_credentials', $form_state['values']['credentials']);
  $conn = twinfield_connect();
  if ($conn) { // Select first office if we were able to connect and no office is selected
    $current_office = twinfield_get_office_code();
    $office_codes = array_keys(twinfield_office_codes($conn));
    if (!empty($offices) && !in_array($current_office, $office_codes))
      variable_set('twinfield_usersync_office_code', $office_codes[0]);
    twinfield_disconnect($conn);
  }
}

/*
 * Get the known fields of the "customer" dimension.
 *
 * @return
 *   An array with as keys partial xpath-like expressions that
 *   describe the XML element to fetch or write, and as values
 *   a human-readable description of the option.
 */
function twinfield_field_options() {
  return array(
    'code' => 'Code',
    'name' => 'Customer name',
    'website' => 'Website',
    'address/name' => 'Address name ("company name")',
    'address/postcode' => 'Postcode',
    'address/city' => 'City',
    'address/country' => 'Country',
    'address/telephone' => 'Telephone',
    'address/telefax' => 'Telefax',
    'address/email' => 'E-mail address',
    // We could do a request to fetch dimension type to get field details for field1-6
    'address/field1' => 'Addresses field1',
    'address/field2' => 'Addresses field2',
    'address/field3' => 'Addresses field3',
    'address/field4' => 'Addresses field4',
    'address/field5' => 'Addresses field5',
    'address/field6' => 'Addresses field6',
    'bank/ascription' => 'Name of bank account holder',
    'bank/accountnumber' => 'Bank account number',
    'bank/city' => 'City of account number holder',
    'financials/ebilling' => 'Provide e-billing?',
    'financials/ebillmail' => 'E-billing e-mail address',
  );
}

/**
 * Menu callback for the twinfield-usersync office selection form.
 */
function twinfield_usersync_admin_office_selection() {
  module_load_include('process.inc', 'twinfield_usersync');
  $conn = twinfield_connect();
  
  $form = array();
  if ($conn === NULL) {
    $form['message']['#value'] = t('Could not connect. Please check the !credentials tab first.', array('!credentials' => l('credentials', 'admin/settings/twinfield-usersync/credentials')));
    return $form;
  }
  $offices = twinfield_office_codes($conn);
  twinfield_disconnect($conn);
  
  $form['office'] = array(
    '#type' => 'select',
    '#title' => t('Office'),
    '#options' => $offices,
    '#default_value' => twinfield_get_office_code()
  );
  
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Submit'),
    '#weight' => 10
  );
  $form['#submit'] = array('twinfield_usersync_admin_office_selection_submit');
  return $form;
}

function twinfield_usersync_admin_office_selection_submit($form, &$form_state) {
  // TODO: We don't need this function?
  variable_set('twinfield_usersync_office_code', $form_state['values']['office']);
}

/**
 * Menu callback for the twinfield-usersync field mapping form.
 */
function twinfield_usersync_admin_field_settings() {
  module_load_include('process.inc', 'twinfield_usersync');
  $twinfields = twinfield_field_options();
  $twinfields = array_merge(array('-' => t('No mapping')), $twinfields);

  $old_selection = variable_get('twinfield_usersync_field_selection', array());
  $form = array('#tree' => true);

  $fields = user_fields();
  if (module_exists('realname'))
    $fields[] = 'realname';
  
  foreach($fields as $field) {
    $form['content_types']['_drupal_profile'][$field] = array(
      '#type' => 'select',
      '#title' => t($field),
      '#options' => $twinfields,
      '#default_value' => (isset($old_selection['_drupal_profile']) ? $old_selection['_drupal_profile'][$field] : $field)
    );
  }

  foreach(content_types() as $type) {
    if (!is_content_profile((object)$type)) continue;
    
    $form['content_types'][$type['type']] = array(
      '#type' => 'fieldset',
      '#title' => t('Content type "!type" fields', array('!type' => $type['type'])),
      '#collapsible' => true
    );

    // Treat title field specially
    $form['content_types'][$type['type']]['title'] = array(
      '#type' => 'select',
      '#title' => 'title',
      '#options' => $twinfields,
      '#default_value' => (isset($old_selection[$type['type']]['title']) ? $old_selection[$type['type']]['title'] : 'title')
    );
    
    foreach($type['fields'] as $name => $field) {
      // Only show types we understand how to represent in XML
      if (!in_array($field['type'], array('text', 'date', 'number_decimal'))) continue;
      
      $form['content_types'][$type['type']][$name] = array(
        '#type' => 'select',
        '#title' => $name,
        '#options' => $twinfields,
        '#default_value' => (isset($old_selection[$type['type']][$name]) ? $old_selection[$type['type']][$name] : $name)
      );
    }
  }
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Submit'),
    '#weight' => 10
  );

  $form['#submit'] = array('twinfield_usersync_admin_field_settings_submit');
  return $form;
}

function twinfield_usersync_admin_field_settings_submit($form, &$form_state) {
  $selection = array();
  foreach($form_state['values']['content_types'] as $type => $fields) {
    foreach($fields as $field_name => $data) {
      $selection[$type][$field_name] = $data;
    }
  }
  variable_set('twinfield_usersync_field_selection', $selection);
}


?>
